/* pdftex-version.h:

   Copyright (C) 1996-2020 Christian Schenk

   This file is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published
   by the Free Software Foundation; either version 2, or (at your
   option) any later version.
   
   This file is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this file; if not, write to the Free Software
   Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
   USA.  */

#include "pdftex_version.h"

#define MIKTEX_COMP_MAJOR_VERSION 4
#define MIKTEX_COMP_MINOR_VERSION 0
#define MIKTEX_COMP_PATCH_VERSION 0


#define MIKTEX_COMP_ORIG_VERSION_STR PDFTEX_VERSION

#define MIKTEX_COMP_COPYRIGHT_STR "© 1982 D. E. Knuth, © 1996-2020 Hàn Thế Thành"

#define MIKTEX_COMP_TM_STR "TeX is a trademark of the American Mathematical Society."

#include <miktex/Version>
